#include <stdio.h>

typedef	long	Char;

/* The UTF-FSS (aka UTF-2) encoding of ISO-10646/Unicode */


long b5tou8(unsigned int );
long gbtou8(unsigned int );
